@@ -1,3 +1,5 @@
+cat("\n\n Basics: vector, matrix, attribute, attr, dim, structure \n\n, t, %*%, outer, crossprod")
+
 
 x <- c(13, 11, 18, 2, 134, 154, 2, 3, 4, 12)
 is.vector(x)
@@ -9,6 +11,7 @@ matrix(x, nrow=2)
 ?matrix
 
 X1m1 <- matrix(x, nrow=2)
+class(X1m1)
 X1m2 <- matrix(x, ncol=5)
 X1m1 == X1m2
 
@@ -24,6 +27,7 @@ attr(X1m3, "dim") <- c(2,5)
 X1m3
 is.vector(X1m3)
 is.matrix(X1m3)
+is.data.frame(X1m3)
 attributes(X1m3)
 identical(X1m1, X1m3)
 
@@ -44,8 +48,10 @@ X1m5
 identical(X1m1, X1m5)
 
 
-X1m6 <- rbind(x[1:5], x[6:10])
-identical(X1m1, X1m5)
+X1m6 <- rbind(x[c(1,3,5,7,9)], x[c(2,4,6,8,10)])
+class(x[1:5])
+class(X1m6)
+identical(X1m1, X1m6)
 
 X1m7 <- cbind(x[1:2], x[3:4], x[5:6], x[7:8],x[9:10])
 identical(X1m1, X1m7)
@@ -62,6 +68,7 @@ x1m7new1 <- drop(x1m7)
 x1m7new1
 identical(x, x1m7new1) #whew
 
+
 x1m7new2 <-  as.vector(x1m7)
 identical(x, x1m7new2)
 
@@ -69,7 +76,7 @@ identical(x, x1m7new2)
 
 ?t
 tX1m1 <- t(X1m1)
-
+tX1m1
 
 X2m1 <- matrix(x, nrow=5, byrow=TRUE)
 X2m1
@@ -79,6 +86,7 @@ identical(X2m1, t(X1m1))
 
 
 X2m2 <- X1m1
+X2m2
 dim(X2m2)
 dim(X2m2) <- c(5,2)
 dim(X2m2)
@@ -104,8 +112,25 @@ outer(x,y, FUN="/")
 outer(x,y, FUN=function(a, b) {b - 2*a})
 
 
-X3 <- matrix( rnorm(10), nrow=2)
+X3 <- matrix(rnorm(10), nrow=2)
 
 crossprod(X1m1, X3)
+t(X1m1) %*% X3
+?crossprod
+
+
+
+## Puzzle
+
+x <- 1:6
+
+X <- data.frame(x1 = x, x2 = x, x3 = x)
+Y <- data.frame(z1 = rnorm(6), z2 = rnorm(6), x3 = rnorm(6))
+
+Z <- cbind(X, Y)
+colnames(Z)
+
+Z2 <- data.frame(X,Y)
+colnames(Z2)
+
 
-t(X1m1, X3)
